#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>


namespace Ui {
    class MainWindow;
}

class MainWindow : public QMainWindow {
    Q_OBJECT
public:
    MainWindow(QWidget *parent = 0);
    ~MainWindow();


protected:
    void changeEvent(QEvent *e);
    void showEvent(QShowEvent* event);
    bool eventFilter(QObject *o, QEvent *e );

    #ifdef Q_WS_HILDON
    bool x11Event ( XEvent * event );
    #endif
private:
    Ui::MainWindow *ui;
    void SetupThisUi();


private slots:

};

#endif // MAINWINDOW_H
